==> istio-model-v1alpha3-6.4.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterProxyMatchFluentImpl<A extends EnvoyFilterProxyMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterProxyMatchFluent<A>{
  public EnvoyFilterProxyMatchFluentImpl() {
  }
  public EnvoyFilterProxyMatchFluentImpl(EnvoyFilterProxyMatch instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withProxyVersion(instance.getProxyVersion()); 
  }
  private Map<String,String> metadata;
  private String proxyVersion;
  public A addToMetadata(String key,String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(Map<String,String> map) {
    if(this.metadata == null && map != null) { this.metadata = new LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(Map<String,String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public Map<String,String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(Map<String,String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new LinkedHashMap(metadata);} return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public String getProxyVersion() {
    return this.proxyVersion;
  }
  public A withProxyVersion(String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  public Boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterProxyMatchFluentImpl that = (EnvoyFilterProxyMatchFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (proxyVersion != null ? !proxyVersion.equals(that.proxyVersion) :that.proxyVersion != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null && !metadata.isEmpty()) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (proxyVersion != null) { sb.append("proxyVersion:"); sb.append(proxyVersion); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterProxyMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterProxyMatchFluentImpl<A extends EnvoyFilterProxyMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterProxyMatchFluent<A>{
  public EnvoyFilterProxyMatchFluentImpl() {
  }
  public EnvoyFilterProxyMatchFluentImpl(EnvoyFilterProxyMatch instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withProxyVersion(instance.getProxyVersion());
    }
  }
  private Map<String,String> metadata;
  private String proxyVersion;
  public A addToMetadata(String key,String value) {
    if(this.metadata == null && key != null && value != null) { this.metadata = new LinkedHashMap(); }
    if(key != null && value != null) {this.metadata.put(key, value);} return (A)this;
  }
  public A addToMetadata(Map<String,String> map) {
    if(this.metadata == null && map != null) { this.metadata = new LinkedHashMap(); }
    if(map != null) { this.metadata.putAll(map);} return (A)this;
  }
  public A removeFromMetadata(String key) {
    if(this.metadata == null) { return (A) this; }
    if(key != null && this.metadata != null) {this.metadata.remove(key);} return (A)this;
  }
  public A removeFromMetadata(Map<String,String> map) {
    if(this.metadata == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.metadata != null){this.metadata.remove(key);}}} return (A)this;
  }
  public Map<String,String> getMetadata() {
    return this.metadata;
  }
  public <K,V>A withMetadata(Map<String,String> metadata) {
    if (metadata == null) { this.metadata =  null;} else {this.metadata = new LinkedHashMap(metadata);} return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public String getProxyVersion() {
    return this.proxyVersion;
  }
  public A withProxyVersion(String proxyVersion) {
    this.proxyVersion=proxyVersion; return (A) this;
  }
  public Boolean hasProxyVersion() {
    return this.proxyVersion != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterProxyMatchFluentImpl that = (EnvoyFilterProxyMatchFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(proxyVersion, that.proxyVersion)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  proxyVersion,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null && !metadata.isEmpty()) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (proxyVersion != null) { sb.append("proxyVersion:"); sb.append(proxyVersion); }
    sb.append("}");
    return sb.toString();
  }
  
}
